### ===================================================================================================================
###                                                       VIIA
###                                                  Objectnr: XXXX
###                                             Structural engineer: Name
### ===================================================================================================================
# TEMPLATE NLTH v2.0
# Copyright VIIA

# Note: The mainscript template is divided into several sections following the steps in NLTH protocol. Functions that
# can be used in each step are placed under the corresponding section. Some functions can only be used under certain
# conditions, please check the docstring before calling them.

# =====================================================================================================================
#                                                    Initial startup
# =====================================================================================================================


# Import the viiaPackage
from viiapackage import *

from rhdhv_fem.fem_math import fem_unit_vector_2_points

# Bools for script control
run_analysis = True

# Initiate the session
project = viia_create_project(project_name='conn_workshop-model', analysis_type='NLTH', version_nr=1)

# Load the model in the json that was created with the model script (model sub folder)
project.viia_read_dump('conn_workshop-model.json', False)

# Assign all shapes to variables
# Ground floor
fstrip1 = project.get_shape(collection_name='fstrips', _id=1)
fstrip2 = project.get_shape(collection_name='fstrips', _id=18)

wall1 = project.get_shape(collection_name='walls', _id=1)
wall2 = project.get_shape(collection_name='walls', _id=2)
wall3 = project.get_shape(collection_name='walls', _id=3)
wall4 = project.get_shape(collection_name='walls', _id=4)

# First floor
wall5 = project.get_shape(collection_name='walls', _id=5)
wall6 = project.get_shape(collection_name='walls', _id=6)
wall7 = project.get_shape(collection_name='walls', _id=7)
wall8 = project.get_shape(collection_name='walls', _id=8)

floor1 = project.get_shape(collection_name='floors', _id=1)

beam1 = project.get_shape(collection_name='beams', _id=1)
beam3 = project.get_shape(collection_name='beams', _id=3)
beam4 = project.get_shape(collection_name='beams', _id=4)
beam5 = project.get_shape(collection_name='beams', _id=5)
beam6 = project.get_shape(collection_name='beams', _id=6)

column1 = project.get_shape(collection_name='columns', _id=1)

# Second floor
wall9 = project.get_shape(collection_name='walls', _id=9)
wall10 = project.get_shape(collection_name='walls', _id=10)
wall11 = project.get_shape(collection_name='walls', _id=11)
wall12 = project.get_shape(collection_name='walls', _id=12)

beam8 = project.get_shape(collection_name='beams', _id=8)
beam9 = project.get_shape(collection_name='beams', _id=9)
beam10 = project.get_shape(collection_name='beams', _id=10)
beam11 = project.get_shape(collection_name='beams', _id=11)
beam12 = project.get_shape(collection_name='beams', _id=12)

# Third floor)
wall13 = project.get_shape(collection_name='walls', _id=13)
wall14 = project.get_shape(collection_name='walls', _id=14)
wall15 = project.get_shape(collection_name='walls', _id=15)
wall16 = project.get_shape(collection_name='walls', _id=16)

floor20 = project.get_shape(collection_name='floors', _id=20)

# Roof
roof21 = project.get_shape(collection_name='roofs', _id=21)
roof22 = project.get_shape(collection_name='roofs', _id=22)
roof23 = project.get_shape(collection_name='roofs', _id=23)
roof24 = project.get_shape(collection_name='roofs', _id=24)

beam13 = project.get_shape(collection_name='beams', _id=13)
beam14 = project.get_shape(collection_name='beams', _id=14)

auto_interfaces_kwargs = {}
auto_hinges_kwargs = {}

custom_functions = []

#### WRITE YOUR SOLUTIONS HERE


####

project.viia_auto_interfaces(**auto_interfaces_kwargs)
project.viia_auto_hinges(**auto_hinges_kwargs)

# Create loads and boundary conditions
project.viia_create_load_combination_static()
project.viia_create_supports('FixedBase')

# Create model in diana
if project.rhdhvDIANA.run_diana:
    project.viia_create_model()
    for function in custom_functions:
        function()

# For fixed base analysis set the materials (temporarily to linear)
# project.viia_linear_properties()

if project.rhdhvDIANA.run_diana and run_analysis:

    project.viia_create_datfile()

    # Linear elastic static calculation (step A1 protocol)
    project.viia_analysis(analysis_nr='A1', run=run_analysis)
